@@ -1,7 +1,9 @@
+from .attachment import *
+from .base import *
+from .block import *
 from .channel import *
 from .client import *
 from .errors import *
-from .attachment import *
 from .httpclient import *
 from .member import *
 from .message import *
@@ -10,4 +12,4 @@ from .state import *
 from .team import *
 from .ws import *
 
-__version__ = "1.4.2"
+__version__ = "1.4.3"
