@@ -1,19 +1,20 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Optional, TypeVar, overload
+from typing import TYPE_CHECKING, TypeVar, Generic
 
 from typing_extensions import ParamSpec
 
-from .. import commands
-from ..channel import Channel
-from ..errors import InvalidArgumentException
-from ..message import Message, DeletedMessage
-from ..route import Route
-from ..team import Team
-from ..view import ViewFrame
+import slack.base
+from slack import commands
+from slack.channel import Channel
+from slack.message import Message, DeletedMessage
+from slack.route import Route
+from slack.team import Team
 
 if TYPE_CHECKING:
     from .command import Command
+    from .bot import Bot
+    from slack.member import Member
 
     P = ParamSpec("P")
 
@@ -23,7 +24,7 @@ else:
 BotT = TypeVar("BotT", bound="Bot")
 
 
-class Context(Message):
+class Context(slack.base.Sendable, Generic[BotT]):
     """A context is a message that is sent to a handler
 
     Attributes
@@ -32,34 +33,52 @@ class Context(Message):
     message: :class:`.Message`
         Message object of context.
 
-    id: :class:`str`
+    message_id: :class:`str`
         Context ID (equals message ID)
 
-    channel_id: :class:`str`
+    id: :class:`str`
         Context channel ID
 
     prefix: :class:`str`
         Message prefix.
     """
+
     def __init__(
             self,
             client: commands.Bot,
             message: Message,
             prefix: str,
-            command: Optional[Command] = None,
+            command: Command,
             *args,
             **kwargs
     ):
         self.args = args
         self.kwargs = kwargs
-        self.command: Optional[Command] = command
+        self.command: Command = command
         self.name = ""
         self.client = client
         self.message = message
         self.prefix = prefix
         self.state = message.state
-        self.id = message.id
-        self.channel_id = self.channel.id
+        self.message_id = message.id
+        self.id = self.channel.id  # channel_id
+        self.http = client.http
+
+    def __eq__(self, other) -> bool:
+        if isinstance(other, Context):
+            try:
+                return self.command.callback == other.command.callback
+
+            except AttributeError:
+                return False
+        return False
+
+    def __repr__(self) -> str:
+        return f"<{self.__class__.__name__} id{self.id}>"
+
+    @property
+    def author(self) -> Member:
+        return self.message.author
 
     @property
     def channel(self) -> Channel:
@@ -93,8 +112,8 @@ class Context(Message):
 
         """
         param = {
-            "channel": self.channel_id,
-            "ts": self.id
+            "channel": self.id,
+            "ts": self.message_id
         }
         message = await self.state.http.delete_message(
             Route(
@@ -104,58 +123,4 @@ class Context(Message):
             ),
             param
         )
-        return DeletedMessage(self.state, message.get("message"))
-
-    @overload
-    async def send(
-            self,
-            text: str = ...,
-    ) -> Context:
-        ...
-
-    @overload
-    async def send(
-            self,
-            view: ViewFrame = ...
-    ) -> Context:
-        ...
-
-    async def send(
-            self,
-            text: Optional[str] = None,
-            view: Optional[ViewFrame] = None
-    ) -> Context:
-        """Send message.
-        Parameters must required `text or view`.
-
-        Parameters
-        ----------
-        text: Optional[:class:`str`]
-        view: Optional[:class:`View`]
-
-        Returns
-        -------
-        :class:`Context`
-            Context object contains message.
-        """
-        if (text is not None and view is not None) or (text is None and view is None):
-            raise InvalidArgumentException()
-        if view is not None:
-            message = await self.message.channel.send(
-                view=view
-            )
-
-        elif text is not None:
-            message = await self.message.channel.send(
-                text=text
-            )
-
-        else:
-            raise ValueError()
-
-        return Context(
-            client=self.client,
-            message=message,
-            prefix=self.prefix,
-            command=self.command
-        )
+        return DeletedMessage(self.state, message.get("message", {}))
